// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_RM_SSAX_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_RM_SSAX_T32_H_

const byte kInstruction_ssax_al_r5_r12_r2[] = {
  0xec, 0xfa, 0x02, 0xf5 // ssax al r5 r12 r2
};
const byte kInstruction_ssax_al_r7_r3_r12[] = {
  0xe3, 0xfa, 0x0c, 0xf7 // ssax al r7 r3 r12
};
const byte kInstruction_ssax_al_r1_r2_r10[] = {
  0xe2, 0xfa, 0x0a, 0xf1 // ssax al r1 r2 r10
};
const byte kInstruction_ssax_al_r2_r7_r1[] = {
  0xe7, 0xfa, 0x01, 0xf2 // ssax al r2 r7 r1
};
const byte kInstruction_ssax_al_r11_r9_r0[] = {
  0xe9, 0xfa, 0x00, 0xfb // ssax al r11 r9 r0
};
const byte kInstruction_ssax_al_r6_r9_r10[] = {
  0xe9, 0xfa, 0x0a, 0xf6 // ssax al r6 r9 r10
};
const byte kInstruction_ssax_al_r0_r5_r0[] = {
  0xe5, 0xfa, 0x00, 0xf0 // ssax al r0 r5 r0
};
const byte kInstruction_ssax_al_r4_r6_r6[] = {
  0xe6, 0xfa, 0x06, 0xf4 // ssax al r4 r6 r6
};
const byte kInstruction_ssax_al_r1_r13_r1[] = {
  0xed, 0xfa, 0x01, 0xf1 // ssax al r1 r13 r1
};
const byte kInstruction_ssax_al_r8_r14_r8[] = {
  0xee, 0xfa, 0x08, 0xf8 // ssax al r8 r14 r8
};
const byte kInstruction_ssax_al_r6_r12_r11[] = {
  0xec, 0xfa, 0x0b, 0xf6 // ssax al r6 r12 r11
};
const byte kInstruction_ssax_al_r7_r2_r8[] = {
  0xe2, 0xfa, 0x08, 0xf7 // ssax al r7 r2 r8
};
const byte kInstruction_ssax_al_r13_r6_r7[] = {
  0xe6, 0xfa, 0x07, 0xfd // ssax al r13 r6 r7
};
const byte kInstruction_ssax_al_r10_r3_r13[] = {
  0xe3, 0xfa, 0x0d, 0xfa // ssax al r10 r3 r13
};
const byte kInstruction_ssax_al_r10_r10_r2[] = {
  0xea, 0xfa, 0x02, 0xfa // ssax al r10 r10 r2
};
const byte kInstruction_ssax_al_r3_r2_r12[] = {
  0xe2, 0xfa, 0x0c, 0xf3 // ssax al r3 r2 r12
};
const byte kInstruction_ssax_al_r0_r9_r7[] = {
  0xe9, 0xfa, 0x07, 0xf0 // ssax al r0 r9 r7
};
const byte kInstruction_ssax_al_r4_r1_r5[] = {
  0xe1, 0xfa, 0x05, 0xf4 // ssax al r4 r1 r5
};
const byte kInstruction_ssax_al_r12_r12_r1[] = {
  0xec, 0xfa, 0x01, 0xfc // ssax al r12 r12 r1
};
const byte kInstruction_ssax_al_r4_r12_r2[] = {
  0xec, 0xfa, 0x02, 0xf4 // ssax al r4 r12 r2
};
const byte kInstruction_ssax_al_r9_r3_r4[] = {
  0xe3, 0xfa, 0x04, 0xf9 // ssax al r9 r3 r4
};
const byte kInstruction_ssax_al_r13_r11_r3[] = {
  0xeb, 0xfa, 0x03, 0xfd // ssax al r13 r11 r3
};
const byte kInstruction_ssax_al_r5_r1_r5[] = {
  0xe1, 0xfa, 0x05, 0xf5 // ssax al r5 r1 r5
};
const byte kInstruction_ssax_al_r14_r6_r2[] = {
  0xe6, 0xfa, 0x02, 0xfe // ssax al r14 r6 r2
};
const byte kInstruction_ssax_al_r1_r2_r0[] = {
  0xe2, 0xfa, 0x00, 0xf1 // ssax al r1 r2 r0
};
const byte kInstruction_ssax_al_r1_r8_r14[] = {
  0xe8, 0xfa, 0x0e, 0xf1 // ssax al r1 r8 r14
};
const byte kInstruction_ssax_al_r12_r9_r10[] = {
  0xe9, 0xfa, 0x0a, 0xfc // ssax al r12 r9 r10
};
const byte kInstruction_ssax_al_r2_r2_r6[] = {
  0xe2, 0xfa, 0x06, 0xf2 // ssax al r2 r2 r6
};
const byte kInstruction_ssax_al_r13_r6_r2[] = {
  0xe6, 0xfa, 0x02, 0xfd // ssax al r13 r6 r2
};
const byte kInstruction_ssax_al_r8_r4_r3[] = {
  0xe4, 0xfa, 0x03, 0xf8 // ssax al r8 r4 r3
};
const byte kInstruction_ssax_al_r7_r11_r3[] = {
  0xeb, 0xfa, 0x03, 0xf7 // ssax al r7 r11 r3
};
const byte kInstruction_ssax_al_r8_r1_r13[] = {
  0xe1, 0xfa, 0x0d, 0xf8 // ssax al r8 r1 r13
};
const byte kInstruction_ssax_al_r1_r11_r6[] = {
  0xeb, 0xfa, 0x06, 0xf1 // ssax al r1 r11 r6
};
const byte kInstruction_ssax_al_r2_r3_r10[] = {
  0xe3, 0xfa, 0x0a, 0xf2 // ssax al r2 r3 r10
};
const byte kInstruction_ssax_al_r0_r9_r0[] = {
  0xe9, 0xfa, 0x00, 0xf0 // ssax al r0 r9 r0
};
const byte kInstruction_ssax_al_r6_r6_r1[] = {
  0xe6, 0xfa, 0x01, 0xf6 // ssax al r6 r6 r1
};
const byte kInstruction_ssax_al_r5_r7_r10[] = {
  0xe7, 0xfa, 0x0a, 0xf5 // ssax al r5 r7 r10
};
const byte kInstruction_ssax_al_r10_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xfa // ssax al r10 r14 r7
};
const byte kInstruction_ssax_al_r8_r2_r12[] = {
  0xe2, 0xfa, 0x0c, 0xf8 // ssax al r8 r2 r12
};
const byte kInstruction_ssax_al_r11_r12_r3[] = {
  0xec, 0xfa, 0x03, 0xfb // ssax al r11 r12 r3
};
const byte kInstruction_ssax_al_r0_r4_r13[] = {
  0xe4, 0xfa, 0x0d, 0xf0 // ssax al r0 r4 r13
};
const byte kInstruction_ssax_al_r13_r0_r8[] = {
  0xe0, 0xfa, 0x08, 0xfd // ssax al r13 r0 r8
};
const byte kInstruction_ssax_al_r7_r14_r12[] = {
  0xee, 0xfa, 0x0c, 0xf7 // ssax al r7 r14 r12
};
const byte kInstruction_ssax_al_r8_r11_r10[] = {
  0xeb, 0xfa, 0x0a, 0xf8 // ssax al r8 r11 r10
};
const byte kInstruction_ssax_al_r8_r13_r14[] = {
  0xed, 0xfa, 0x0e, 0xf8 // ssax al r8 r13 r14
};
const byte kInstruction_ssax_al_r13_r7_r1[] = {
  0xe7, 0xfa, 0x01, 0xfd // ssax al r13 r7 r1
};
const byte kInstruction_ssax_al_r10_r0_r14[] = {
  0xe0, 0xfa, 0x0e, 0xfa // ssax al r10 r0 r14
};
const byte kInstruction_ssax_al_r6_r4_r12[] = {
  0xe4, 0xfa, 0x0c, 0xf6 // ssax al r6 r4 r12
};
const byte kInstruction_ssax_al_r8_r8_r12[] = {
  0xe8, 0xfa, 0x0c, 0xf8 // ssax al r8 r8 r12
};
const byte kInstruction_ssax_al_r10_r9_r4[] = {
  0xe9, 0xfa, 0x04, 0xfa // ssax al r10 r9 r4
};
const byte kInstruction_ssax_al_r14_r9_r8[] = {
  0xe9, 0xfa, 0x08, 0xfe // ssax al r14 r9 r8
};
const byte kInstruction_ssax_al_r9_r1_r0[] = {
  0xe1, 0xfa, 0x00, 0xf9 // ssax al r9 r1 r0
};
const byte kInstruction_ssax_al_r14_r4_r11[] = {
  0xe4, 0xfa, 0x0b, 0xfe // ssax al r14 r4 r11
};
const byte kInstruction_ssax_al_r13_r1_r12[] = {
  0xe1, 0xfa, 0x0c, 0xfd // ssax al r13 r1 r12
};
const byte kInstruction_ssax_al_r6_r14_r5[] = {
  0xee, 0xfa, 0x05, 0xf6 // ssax al r6 r14 r5
};
const byte kInstruction_ssax_al_r7_r7_r6[] = {
  0xe7, 0xfa, 0x06, 0xf7 // ssax al r7 r7 r6
};
const byte kInstruction_ssax_al_r6_r14_r0[] = {
  0xee, 0xfa, 0x00, 0xf6 // ssax al r6 r14 r0
};
const byte kInstruction_ssax_al_r7_r5_r11[] = {
  0xe5, 0xfa, 0x0b, 0xf7 // ssax al r7 r5 r11
};
const byte kInstruction_ssax_al_r9_r10_r9[] = {
  0xea, 0xfa, 0x09, 0xf9 // ssax al r9 r10 r9
};
const byte kInstruction_ssax_al_r4_r5_r0[] = {
  0xe5, 0xfa, 0x00, 0xf4 // ssax al r4 r5 r0
};
const byte kInstruction_ssax_al_r3_r11_r2[] = {
  0xeb, 0xfa, 0x02, 0xf3 // ssax al r3 r11 r2
};
const byte kInstruction_ssax_al_r1_r4_r3[] = {
  0xe4, 0xfa, 0x03, 0xf1 // ssax al r1 r4 r3
};
const byte kInstruction_ssax_al_r13_r14_r6[] = {
  0xee, 0xfa, 0x06, 0xfd // ssax al r13 r14 r6
};
const byte kInstruction_ssax_al_r1_r8_r13[] = {
  0xe8, 0xfa, 0x0d, 0xf1 // ssax al r1 r8 r13
};
const byte kInstruction_ssax_al_r4_r2_r7[] = {
  0xe2, 0xfa, 0x07, 0xf4 // ssax al r4 r2 r7
};
const byte kInstruction_ssax_al_r1_r11_r3[] = {
  0xeb, 0xfa, 0x03, 0xf1 // ssax al r1 r11 r3
};
const byte kInstruction_ssax_al_r9_r3_r6[] = {
  0xe3, 0xfa, 0x06, 0xf9 // ssax al r9 r3 r6
};
const byte kInstruction_ssax_al_r0_r10_r5[] = {
  0xea, 0xfa, 0x05, 0xf0 // ssax al r0 r10 r5
};
const byte kInstruction_ssax_al_r5_r7_r2[] = {
  0xe7, 0xfa, 0x02, 0xf5 // ssax al r5 r7 r2
};
const byte kInstruction_ssax_al_r1_r14_r9[] = {
  0xee, 0xfa, 0x09, 0xf1 // ssax al r1 r14 r9
};
const byte kInstruction_ssax_al_r9_r12_r11[] = {
  0xec, 0xfa, 0x0b, 0xf9 // ssax al r9 r12 r11
};
const byte kInstruction_ssax_al_r0_r11_r8[] = {
  0xeb, 0xfa, 0x08, 0xf0 // ssax al r0 r11 r8
};
const byte kInstruction_ssax_al_r9_r10_r12[] = {
  0xea, 0xfa, 0x0c, 0xf9 // ssax al r9 r10 r12
};
const byte kInstruction_ssax_al_r8_r5_r5[] = {
  0xe5, 0xfa, 0x05, 0xf8 // ssax al r8 r5 r5
};
const byte kInstruction_ssax_al_r10_r3_r10[] = {
  0xe3, 0xfa, 0x0a, 0xfa // ssax al r10 r3 r10
};
const byte kInstruction_ssax_al_r13_r5_r8[] = {
  0xe5, 0xfa, 0x08, 0xfd // ssax al r13 r5 r8
};
const byte kInstruction_ssax_al_r11_r4_r2[] = {
  0xe4, 0xfa, 0x02, 0xfb // ssax al r11 r4 r2
};
const byte kInstruction_ssax_al_r1_r10_r7[] = {
  0xea, 0xfa, 0x07, 0xf1 // ssax al r1 r10 r7
};
const byte kInstruction_ssax_al_r12_r4_r1[] = {
  0xe4, 0xfa, 0x01, 0xfc // ssax al r12 r4 r1
};
const byte kInstruction_ssax_al_r11_r14_r8[] = {
  0xee, 0xfa, 0x08, 0xfb // ssax al r11 r14 r8
};
const byte kInstruction_ssax_al_r1_r11_r8[] = {
  0xeb, 0xfa, 0x08, 0xf1 // ssax al r1 r11 r8
};
const byte kInstruction_ssax_al_r3_r11_r10[] = {
  0xeb, 0xfa, 0x0a, 0xf3 // ssax al r3 r11 r10
};
const byte kInstruction_ssax_al_r6_r7_r0[] = {
  0xe7, 0xfa, 0x00, 0xf6 // ssax al r6 r7 r0
};
const byte kInstruction_ssax_al_r6_r13_r9[] = {
  0xed, 0xfa, 0x09, 0xf6 // ssax al r6 r13 r9
};
const byte kInstruction_ssax_al_r9_r14_r0[] = {
  0xee, 0xfa, 0x00, 0xf9 // ssax al r9 r14 r0
};
const byte kInstruction_ssax_al_r6_r8_r2[] = {
  0xe8, 0xfa, 0x02, 0xf6 // ssax al r6 r8 r2
};
const byte kInstruction_ssax_al_r7_r11_r12[] = {
  0xeb, 0xfa, 0x0c, 0xf7 // ssax al r7 r11 r12
};
const byte kInstruction_ssax_al_r9_r3_r0[] = {
  0xe3, 0xfa, 0x00, 0xf9 // ssax al r9 r3 r0
};
const byte kInstruction_ssax_al_r5_r3_r5[] = {
  0xe3, 0xfa, 0x05, 0xf5 // ssax al r5 r3 r5
};
const byte kInstruction_ssax_al_r5_r10_r8[] = {
  0xea, 0xfa, 0x08, 0xf5 // ssax al r5 r10 r8
};
const byte kInstruction_ssax_al_r12_r4_r13[] = {
  0xe4, 0xfa, 0x0d, 0xfc // ssax al r12 r4 r13
};
const byte kInstruction_ssax_al_r7_r12_r10[] = {
  0xec, 0xfa, 0x0a, 0xf7 // ssax al r7 r12 r10
};
const byte kInstruction_ssax_al_r6_r13_r11[] = {
  0xed, 0xfa, 0x0b, 0xf6 // ssax al r6 r13 r11
};
const byte kInstruction_ssax_al_r5_r3_r7[] = {
  0xe3, 0xfa, 0x07, 0xf5 // ssax al r5 r3 r7
};
const byte kInstruction_ssax_al_r11_r4_r6[] = {
  0xe4, 0xfa, 0x06, 0xfb // ssax al r11 r4 r6
};
const byte kInstruction_ssax_al_r10_r2_r3[] = {
  0xe2, 0xfa, 0x03, 0xfa // ssax al r10 r2 r3
};
const byte kInstruction_ssax_al_r0_r2_r1[] = {
  0xe2, 0xfa, 0x01, 0xf0 // ssax al r0 r2 r1
};
const byte kInstruction_ssax_al_r11_r5_r7[] = {
  0xe5, 0xfa, 0x07, 0xfb // ssax al r11 r5 r7
};
const byte kInstruction_ssax_al_r14_r10_r1[] = {
  0xea, 0xfa, 0x01, 0xfe // ssax al r14 r10 r1
};
const byte kInstruction_ssax_al_r1_r4_r1[] = {
  0xe4, 0xfa, 0x01, 0xf1 // ssax al r1 r4 r1
};
const byte kInstruction_ssax_al_r9_r10_r11[] = {
  0xea, 0xfa, 0x0b, 0xf9 // ssax al r9 r10 r11
};
const byte kInstruction_ssax_al_r6_r8_r0[] = {
  0xe8, 0xfa, 0x00, 0xf6 // ssax al r6 r8 r0
};
const byte kInstruction_ssax_al_r0_r10_r11[] = {
  0xea, 0xfa, 0x0b, 0xf0 // ssax al r0 r10 r11
};
const byte kInstruction_ssax_al_r14_r1_r4[] = {
  0xe1, 0xfa, 0x04, 0xfe // ssax al r14 r1 r4
};
const byte kInstruction_ssax_al_r7_r9_r5[] = {
  0xe9, 0xfa, 0x05, 0xf7 // ssax al r7 r9 r5
};
const byte kInstruction_ssax_al_r13_r4_r2[] = {
  0xe4, 0xfa, 0x02, 0xfd // ssax al r13 r4 r2
};
const byte kInstruction_ssax_al_r5_r6_r3[] = {
  0xe6, 0xfa, 0x03, 0xf5 // ssax al r5 r6 r3
};
const byte kInstruction_ssax_al_r13_r4_r8[] = {
  0xe4, 0xfa, 0x08, 0xfd // ssax al r13 r4 r8
};
const byte kInstruction_ssax_al_r11_r11_r12[] = {
  0xeb, 0xfa, 0x0c, 0xfb // ssax al r11 r11 r12
};
const byte kInstruction_ssax_al_r3_r12_r6[] = {
  0xec, 0xfa, 0x06, 0xf3 // ssax al r3 r12 r6
};
const byte kInstruction_ssax_al_r4_r10_r1[] = {
  0xea, 0xfa, 0x01, 0xf4 // ssax al r4 r10 r1
};
const byte kInstruction_ssax_al_r7_r8_r12[] = {
  0xe8, 0xfa, 0x0c, 0xf7 // ssax al r7 r8 r12
};
const byte kInstruction_ssax_al_r11_r3_r3[] = {
  0xe3, 0xfa, 0x03, 0xfb // ssax al r11 r3 r3
};
const byte kInstruction_ssax_al_r14_r6_r6[] = {
  0xe6, 0xfa, 0x06, 0xfe // ssax al r14 r6 r6
};
const byte kInstruction_ssax_al_r1_r12_r1[] = {
  0xec, 0xfa, 0x01, 0xf1 // ssax al r1 r12 r1
};
const byte kInstruction_ssax_al_r13_r5_r7[] = {
  0xe5, 0xfa, 0x07, 0xfd // ssax al r13 r5 r7
};
const byte kInstruction_ssax_al_r6_r10_r8[] = {
  0xea, 0xfa, 0x08, 0xf6 // ssax al r6 r10 r8
};
const byte kInstruction_ssax_al_r7_r13_r5[] = {
  0xed, 0xfa, 0x05, 0xf7 // ssax al r7 r13 r5
};
const byte kInstruction_ssax_al_r12_r13_r4[] = {
  0xed, 0xfa, 0x04, 0xfc // ssax al r12 r13 r4
};
const byte kInstruction_ssax_al_r7_r0_r8[] = {
  0xe0, 0xfa, 0x08, 0xf7 // ssax al r7 r0 r8
};
const byte kInstruction_ssax_al_r7_r11_r9[] = {
  0xeb, 0xfa, 0x09, 0xf7 // ssax al r7 r11 r9
};
const byte kInstruction_ssax_al_r8_r9_r1[] = {
  0xe9, 0xfa, 0x01, 0xf8 // ssax al r8 r9 r1
};
const byte kInstruction_ssax_al_r14_r5_r10[] = {
  0xe5, 0xfa, 0x0a, 0xfe // ssax al r14 r5 r10
};
const byte kInstruction_ssax_al_r4_r9_r14[] = {
  0xe9, 0xfa, 0x0e, 0xf4 // ssax al r4 r9 r14
};
const byte kInstruction_ssax_al_r10_r14_r9[] = {
  0xee, 0xfa, 0x09, 0xfa // ssax al r10 r14 r9
};
const byte kInstruction_ssax_al_r0_r1_r11[] = {
  0xe1, 0xfa, 0x0b, 0xf0 // ssax al r0 r1 r11
};
const byte kInstruction_ssax_al_r11_r0_r11[] = {
  0xe0, 0xfa, 0x0b, 0xfb // ssax al r11 r0 r11
};
const byte kInstruction_ssax_al_r10_r10_r7[] = {
  0xea, 0xfa, 0x07, 0xfa // ssax al r10 r10 r7
};
const byte kInstruction_ssax_al_r8_r12_r7[] = {
  0xec, 0xfa, 0x07, 0xf8 // ssax al r8 r12 r7
};
const byte kInstruction_ssax_al_r9_r4_r10[] = {
  0xe4, 0xfa, 0x0a, 0xf9 // ssax al r9 r4 r10
};
const byte kInstruction_ssax_al_r8_r11_r14[] = {
  0xeb, 0xfa, 0x0e, 0xf8 // ssax al r8 r11 r14
};
const byte kInstruction_ssax_al_r8_r4_r7[] = {
  0xe4, 0xfa, 0x07, 0xf8 // ssax al r8 r4 r7
};
const byte kInstruction_ssax_al_r13_r9_r11[] = {
  0xe9, 0xfa, 0x0b, 0xfd // ssax al r13 r9 r11
};
const byte kInstruction_ssax_al_r2_r5_r7[] = {
  0xe5, 0xfa, 0x07, 0xf2 // ssax al r2 r5 r7
};
const byte kInstruction_ssax_al_r9_r6_r8[] = {
  0xe6, 0xfa, 0x08, 0xf9 // ssax al r9 r6 r8
};
const byte kInstruction_ssax_al_r2_r4_r10[] = {
  0xe4, 0xfa, 0x0a, 0xf2 // ssax al r2 r4 r10
};
const byte kInstruction_ssax_al_r2_r9_r4[] = {
  0xe9, 0xfa, 0x04, 0xf2 // ssax al r2 r9 r4
};
const byte kInstruction_ssax_al_r12_r8_r12[] = {
  0xe8, 0xfa, 0x0c, 0xfc // ssax al r12 r8 r12
};
const byte kInstruction_ssax_al_r0_r12_r2[] = {
  0xec, 0xfa, 0x02, 0xf0 // ssax al r0 r12 r2
};
const byte kInstruction_ssax_al_r4_r11_r13[] = {
  0xeb, 0xfa, 0x0d, 0xf4 // ssax al r4 r11 r13
};
const byte kInstruction_ssax_al_r7_r12_r14[] = {
  0xec, 0xfa, 0x0e, 0xf7 // ssax al r7 r12 r14
};
const byte kInstruction_ssax_al_r4_r10_r3[] = {
  0xea, 0xfa, 0x03, 0xf4 // ssax al r4 r10 r3
};
const byte kInstruction_ssax_al_r5_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xf5 // ssax al r5 r14 r7
};
const byte kInstruction_ssax_al_r1_r6_r10[] = {
  0xe6, 0xfa, 0x0a, 0xf1 // ssax al r1 r6 r10
};
const byte kInstruction_ssax_al_r0_r10_r10[] = {
  0xea, 0xfa, 0x0a, 0xf0 // ssax al r0 r10 r10
};
const byte kInstruction_ssax_al_r6_r3_r3[] = {
  0xe3, 0xfa, 0x03, 0xf6 // ssax al r6 r3 r3
};
const byte kInstruction_ssax_al_r2_r14_r6[] = {
  0xee, 0xfa, 0x06, 0xf2 // ssax al r2 r14 r6
};
const byte kInstruction_ssax_al_r7_r4_r2[] = {
  0xe4, 0xfa, 0x02, 0xf7 // ssax al r7 r4 r2
};
const byte kInstruction_ssax_al_r3_r7_r9[] = {
  0xe7, 0xfa, 0x09, 0xf3 // ssax al r3 r7 r9
};
const byte kInstruction_ssax_al_r0_r4_r12[] = {
  0xe4, 0xfa, 0x0c, 0xf0 // ssax al r0 r4 r12
};
const byte kInstruction_ssax_al_r8_r14_r11[] = {
  0xee, 0xfa, 0x0b, 0xf8 // ssax al r8 r14 r11
};
const byte kInstruction_ssax_al_r2_r8_r11[] = {
  0xe8, 0xfa, 0x0b, 0xf2 // ssax al r2 r8 r11
};
const byte kInstruction_ssax_al_r14_r11_r8[] = {
  0xeb, 0xfa, 0x08, 0xfe // ssax al r14 r11 r8
};
const byte kInstruction_ssax_al_r5_r10_r12[] = {
  0xea, 0xfa, 0x0c, 0xf5 // ssax al r5 r10 r12
};
const byte kInstruction_ssax_al_r0_r12_r5[] = {
  0xec, 0xfa, 0x05, 0xf0 // ssax al r0 r12 r5
};
const byte kInstruction_ssax_al_r4_r4_r7[] = {
  0xe4, 0xfa, 0x07, 0xf4 // ssax al r4 r4 r7
};
const byte kInstruction_ssax_al_r5_r2_r10[] = {
  0xe2, 0xfa, 0x0a, 0xf5 // ssax al r5 r2 r10
};
const byte kInstruction_ssax_al_r14_r0_r0[] = {
  0xe0, 0xfa, 0x00, 0xfe // ssax al r14 r0 r0
};
const byte kInstruction_ssax_al_r1_r14_r4[] = {
  0xee, 0xfa, 0x04, 0xf1 // ssax al r1 r14 r4
};
const byte kInstruction_ssax_al_r1_r0_r2[] = {
  0xe0, 0xfa, 0x02, 0xf1 // ssax al r1 r0 r2
};
const byte kInstruction_ssax_al_r11_r10_r7[] = {
  0xea, 0xfa, 0x07, 0xfb // ssax al r11 r10 r7
};
const byte kInstruction_ssax_al_r13_r10_r4[] = {
  0xea, 0xfa, 0x04, 0xfd // ssax al r13 r10 r4
};
const byte kInstruction_ssax_al_r13_r1_r9[] = {
  0xe1, 0xfa, 0x09, 0xfd // ssax al r13 r1 r9
};
const byte kInstruction_ssax_al_r8_r1_r9[] = {
  0xe1, 0xfa, 0x09, 0xf8 // ssax al r8 r1 r9
};
const byte kInstruction_ssax_al_r6_r3_r9[] = {
  0xe3, 0xfa, 0x09, 0xf6 // ssax al r6 r3 r9
};
const byte kInstruction_ssax_al_r10_r6_r8[] = {
  0xe6, 0xfa, 0x08, 0xfa // ssax al r10 r6 r8
};
const byte kInstruction_ssax_al_r6_r11_r9[] = {
  0xeb, 0xfa, 0x09, 0xf6 // ssax al r6 r11 r9
};
const byte kInstruction_ssax_al_r1_r13_r14[] = {
  0xed, 0xfa, 0x0e, 0xf1 // ssax al r1 r13 r14
};
const byte kInstruction_ssax_al_r1_r14_r12[] = {
  0xee, 0xfa, 0x0c, 0xf1 // ssax al r1 r14 r12
};
const byte kInstruction_ssax_al_r0_r1_r4[] = {
  0xe1, 0xfa, 0x04, 0xf0 // ssax al r0 r1 r4
};
const byte kInstruction_ssax_al_r8_r13_r1[] = {
  0xed, 0xfa, 0x01, 0xf8 // ssax al r8 r13 r1
};
const byte kInstruction_ssax_al_r7_r14_r5[] = {
  0xee, 0xfa, 0x05, 0xf7 // ssax al r7 r14 r5
};
const byte kInstruction_ssax_al_r5_r13_r8[] = {
  0xed, 0xfa, 0x08, 0xf5 // ssax al r5 r13 r8
};
const byte kInstruction_ssax_al_r11_r10_r13[] = {
  0xea, 0xfa, 0x0d, 0xfb // ssax al r11 r10 r13
};
const byte kInstruction_ssax_al_r7_r13_r2[] = {
  0xed, 0xfa, 0x02, 0xf7 // ssax al r7 r13 r2
};
const byte kInstruction_ssax_al_r2_r2_r13[] = {
  0xe2, 0xfa, 0x0d, 0xf2 // ssax al r2 r2 r13
};
const byte kInstruction_ssax_al_r1_r7_r5[] = {
  0xe7, 0xfa, 0x05, 0xf1 // ssax al r1 r7 r5
};
const byte kInstruction_ssax_al_r12_r6_r12[] = {
  0xe6, 0xfa, 0x0c, 0xfc // ssax al r12 r6 r12
};
const byte kInstruction_ssax_al_r5_r9_r11[] = {
  0xe9, 0xfa, 0x0b, 0xf5 // ssax al r5 r9 r11
};
const byte kInstruction_ssax_al_r12_r7_r1[] = {
  0xe7, 0xfa, 0x01, 0xfc // ssax al r12 r7 r1
};
const byte kInstruction_ssax_al_r13_r9_r9[] = {
  0xe9, 0xfa, 0x09, 0xfd // ssax al r13 r9 r9
};
const byte kInstruction_ssax_al_r10_r4_r13[] = {
  0xe4, 0xfa, 0x0d, 0xfa // ssax al r10 r4 r13
};
const byte kInstruction_ssax_al_r9_r2_r10[] = {
  0xe2, 0xfa, 0x0a, 0xf9 // ssax al r9 r2 r10
};
const byte kInstruction_ssax_al_r1_r5_r13[] = {
  0xe5, 0xfa, 0x0d, 0xf1 // ssax al r1 r5 r13
};
const byte kInstruction_ssax_al_r12_r3_r9[] = {
  0xe3, 0xfa, 0x09, 0xfc // ssax al r12 r3 r9
};
const byte kInstruction_ssax_al_r6_r3_r0[] = {
  0xe3, 0xfa, 0x00, 0xf6 // ssax al r6 r3 r0
};
const byte kInstruction_ssax_al_r9_r8_r8[] = {
  0xe8, 0xfa, 0x08, 0xf9 // ssax al r9 r8 r8
};
const byte kInstruction_ssax_al_r6_r3_r4[] = {
  0xe3, 0xfa, 0x04, 0xf6 // ssax al r6 r3 r4
};
const byte kInstruction_ssax_al_r12_r9_r0[] = {
  0xe9, 0xfa, 0x00, 0xfc // ssax al r12 r9 r0
};
const byte kInstruction_ssax_al_r4_r10_r0[] = {
  0xea, 0xfa, 0x00, 0xf4 // ssax al r4 r10 r0
};
const byte kInstruction_ssax_al_r3_r13_r4[] = {
  0xed, 0xfa, 0x04, 0xf3 // ssax al r3 r13 r4
};
const byte kInstruction_ssax_al_r2_r10_r14[] = {
  0xea, 0xfa, 0x0e, 0xf2 // ssax al r2 r10 r14
};
const byte kInstruction_ssax_al_r3_r9_r8[] = {
  0xe9, 0xfa, 0x08, 0xf3 // ssax al r3 r9 r8
};
const byte kInstruction_ssax_al_r12_r4_r8[] = {
  0xe4, 0xfa, 0x08, 0xfc // ssax al r12 r4 r8
};
const byte kInstruction_ssax_al_r2_r1_r11[] = {
  0xe1, 0xfa, 0x0b, 0xf2 // ssax al r2 r1 r11
};
const byte kInstruction_ssax_al_r1_r7_r0[] = {
  0xe7, 0xfa, 0x00, 0xf1 // ssax al r1 r7 r0
};
const byte kInstruction_ssax_al_r0_r1_r2[] = {
  0xe1, 0xfa, 0x02, 0xf0 // ssax al r0 r1 r2
};
const byte kInstruction_ssax_al_r11_r12_r7[] = {
  0xec, 0xfa, 0x07, 0xfb // ssax al r11 r12 r7
};
const byte kInstruction_ssax_al_r12_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xfc // ssax al r12 r14 r7
};
const byte kInstruction_ssax_al_r0_r3_r10[] = {
  0xe3, 0xfa, 0x0a, 0xf0 // ssax al r0 r3 r10
};
const byte kInstruction_ssax_al_r3_r6_r7[] = {
  0xe6, 0xfa, 0x07, 0xf3 // ssax al r3 r6 r7
};
const byte kInstruction_ssax_al_r0_r10_r1[] = {
  0xea, 0xfa, 0x01, 0xf0 // ssax al r0 r10 r1
};
const byte kInstruction_ssax_al_r8_r11_r5[] = {
  0xeb, 0xfa, 0x05, 0xf8 // ssax al r8 r11 r5
};
const byte kInstruction_ssax_al_r1_r10_r8[] = {
  0xea, 0xfa, 0x08, 0xf1 // ssax al r1 r10 r8
};
const byte kInstruction_ssax_al_r7_r8_r5[] = {
  0xe8, 0xfa, 0x05, 0xf7 // ssax al r7 r8 r5
};
const byte kInstruction_ssax_al_r9_r9_r2[] = {
  0xe9, 0xfa, 0x02, 0xf9 // ssax al r9 r9 r2
};
const byte kInstruction_ssax_al_r13_r13_r0[] = {
  0xed, 0xfa, 0x00, 0xfd // ssax al r13 r13 r0
};
const byte kInstruction_ssax_al_r9_r10_r5[] = {
  0xea, 0xfa, 0x05, 0xf9 // ssax al r9 r10 r5
};
const byte kInstruction_ssax_al_r6_r6_r14[] = {
  0xe6, 0xfa, 0x0e, 0xf6 // ssax al r6 r6 r14
};
const byte kInstruction_ssax_al_r1_r8_r5[] = {
  0xe8, 0xfa, 0x05, 0xf1 // ssax al r1 r8 r5
};
const byte kInstruction_ssax_al_r1_r4_r8[] = {
  0xe4, 0xfa, 0x08, 0xf1 // ssax al r1 r4 r8
};
const byte kInstruction_ssax_al_r0_r2_r12[] = {
  0xe2, 0xfa, 0x0c, 0xf0 // ssax al r0 r2 r12
};
const byte kInstruction_ssax_al_r5_r14_r1[] = {
  0xee, 0xfa, 0x01, 0xf5 // ssax al r5 r14 r1
};
const byte kInstruction_ssax_al_r2_r1_r5[] = {
  0xe1, 0xfa, 0x05, 0xf2 // ssax al r2 r1 r5
};
const byte kInstruction_ssax_al_r11_r11_r6[] = {
  0xeb, 0xfa, 0x06, 0xfb // ssax al r11 r11 r6
};
const byte kInstruction_ssax_al_r3_r11_r1[] = {
  0xeb, 0xfa, 0x01, 0xf3 // ssax al r3 r11 r1
};
const byte kInstruction_ssax_al_r13_r14_r9[] = {
  0xee, 0xfa, 0x09, 0xfd // ssax al r13 r14 r9
};
const byte kInstruction_ssax_al_r7_r1_r5[] = {
  0xe1, 0xfa, 0x05, 0xf7 // ssax al r7 r1 r5
};
const byte kInstruction_ssax_al_r10_r14_r3[] = {
  0xee, 0xfa, 0x03, 0xfa // ssax al r10 r14 r3
};
const byte kInstruction_ssax_al_r5_r6_r14[] = {
  0xe6, 0xfa, 0x0e, 0xf5 // ssax al r5 r6 r14
};
const byte kInstruction_ssax_al_r1_r7_r7[] = {
  0xe7, 0xfa, 0x07, 0xf1 // ssax al r1 r7 r7
};
const byte kInstruction_ssax_al_r12_r5_r14[] = {
  0xe5, 0xfa, 0x0e, 0xfc // ssax al r12 r5 r14
};
const byte kInstruction_ssax_al_r10_r5_r1[] = {
  0xe5, 0xfa, 0x01, 0xfa // ssax al r10 r5 r1
};
const byte kInstruction_ssax_al_r10_r8_r3[] = {
  0xe8, 0xfa, 0x03, 0xfa // ssax al r10 r8 r3
};
const byte kInstruction_ssax_al_r4_r6_r5[] = {
  0xe6, 0xfa, 0x05, 0xf4 // ssax al r4 r6 r5
};
const byte kInstruction_ssax_al_r4_r3_r2[] = {
  0xe3, 0xfa, 0x02, 0xf4 // ssax al r4 r3 r2
};
const byte kInstruction_ssax_al_r10_r13_r13[] = {
  0xed, 0xfa, 0x0d, 0xfa // ssax al r10 r13 r13
};
const byte kInstruction_ssax_al_r1_r10_r4[] = {
  0xea, 0xfa, 0x04, 0xf1 // ssax al r1 r10 r4
};
const byte kInstruction_ssax_al_r8_r10_r12[] = {
  0xea, 0xfa, 0x0c, 0xf8 // ssax al r8 r10 r12
};
const byte kInstruction_ssax_al_r6_r0_r13[] = {
  0xe0, 0xfa, 0x0d, 0xf6 // ssax al r6 r0 r13
};
const byte kInstruction_ssax_al_r1_r12_r0[] = {
  0xec, 0xfa, 0x00, 0xf1 // ssax al r1 r12 r0
};
const byte kInstruction_ssax_al_r4_r13_r1[] = {
  0xed, 0xfa, 0x01, 0xf4 // ssax al r4 r13 r1
};
const byte kInstruction_ssax_al_r10_r0_r0[] = {
  0xe0, 0xfa, 0x00, 0xfa // ssax al r10 r0 r0
};
const byte kInstruction_ssax_al_r13_r6_r4[] = {
  0xe6, 0xfa, 0x04, 0xfd // ssax al r13 r6 r4
};
const byte kInstruction_ssax_al_r0_r3_r14[] = {
  0xe3, 0xfa, 0x0e, 0xf0 // ssax al r0 r3 r14
};
const byte kInstruction_ssax_al_r7_r11_r2[] = {
  0xeb, 0xfa, 0x02, 0xf7 // ssax al r7 r11 r2
};
const byte kInstruction_ssax_al_r9_r11_r12[] = {
  0xeb, 0xfa, 0x0c, 0xf9 // ssax al r9 r11 r12
};
const byte kInstruction_ssax_al_r2_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xf2 // ssax al r2 r14 r7
};
const byte kInstruction_ssax_al_r10_r14_r8[] = {
  0xee, 0xfa, 0x08, 0xfa // ssax al r10 r14 r8
};
const byte kInstruction_ssax_al_r1_r3_r2[] = {
  0xe3, 0xfa, 0x02, 0xf1 // ssax al r1 r3 r2
};
const byte kInstruction_ssax_al_r0_r1_r8[] = {
  0xe1, 0xfa, 0x08, 0xf0 // ssax al r0 r1 r8
};
const byte kInstruction_ssax_al_r2_r9_r13[] = {
  0xe9, 0xfa, 0x0d, 0xf2 // ssax al r2 r9 r13
};
const byte kInstruction_ssax_al_r2_r3_r5[] = {
  0xe3, 0xfa, 0x05, 0xf2 // ssax al r2 r3 r5
};
const byte kInstruction_ssax_al_r13_r9_r3[] = {
  0xe9, 0xfa, 0x03, 0xfd // ssax al r13 r9 r3
};
const byte kInstruction_ssax_al_r3_r8_r8[] = {
  0xe8, 0xfa, 0x08, 0xf3 // ssax al r3 r8 r8
};
const byte kInstruction_ssax_al_r0_r8_r7[] = {
  0xe8, 0xfa, 0x07, 0xf0 // ssax al r0 r8 r7
};
const byte kInstruction_ssax_al_r9_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xf9 // ssax al r9 r14 r7
};
const byte kInstruction_ssax_al_r10_r3_r11[] = {
  0xe3, 0xfa, 0x0b, 0xfa // ssax al r10 r3 r11
};
const byte kInstruction_ssax_al_r1_r14_r13[] = {
  0xee, 0xfa, 0x0d, 0xf1 // ssax al r1 r14 r13
};
const byte kInstruction_ssax_al_r14_r4_r1[] = {
  0xe4, 0xfa, 0x01, 0xfe // ssax al r14 r4 r1
};
const byte kInstruction_ssax_al_r12_r12_r4[] = {
  0xec, 0xfa, 0x04, 0xfc // ssax al r12 r12 r4
};
const byte kInstruction_ssax_al_r0_r12_r0[] = {
  0xec, 0xfa, 0x00, 0xf0 // ssax al r0 r12 r0
};
const byte kInstruction_ssax_al_r1_r5_r1[] = {
  0xe5, 0xfa, 0x01, 0xf1 // ssax al r1 r5 r1
};
const byte kInstruction_ssax_al_r3_r9_r6[] = {
  0xe9, 0xfa, 0x06, 0xf3 // ssax al r3 r9 r6
};
const byte kInstruction_ssax_al_r2_r11_r0[] = {
  0xeb, 0xfa, 0x00, 0xf2 // ssax al r2 r11 r0
};
const byte kInstruction_ssax_al_r2_r6_r11[] = {
  0xe6, 0xfa, 0x0b, 0xf2 // ssax al r2 r6 r11
};
const byte kInstruction_ssax_al_r8_r12_r8[] = {
  0xec, 0xfa, 0x08, 0xf8 // ssax al r8 r12 r8
};
const byte kInstruction_ssax_al_r2_r12_r10[] = {
  0xec, 0xfa, 0x0a, 0xf2 // ssax al r2 r12 r10
};
const byte kInstruction_ssax_al_r4_r4_r10[] = {
  0xe4, 0xfa, 0x0a, 0xf4 // ssax al r4 r4 r10
};
const byte kInstruction_ssax_al_r6_r14_r7[] = {
  0xee, 0xfa, 0x07, 0xf6 // ssax al r6 r14 r7
};
const byte kInstruction_ssax_al_r11_r10_r14[] = {
  0xea, 0xfa, 0x0e, 0xfb // ssax al r11 r10 r14
};
const byte kInstruction_ssax_al_r13_r0_r5[] = {
  0xe0, 0xfa, 0x05, 0xfd // ssax al r13 r0 r5
};
const byte kInstruction_ssax_al_r4_r3_r7[] = {
  0xe3, 0xfa, 0x07, 0xf4 // ssax al r4 r3 r7
};
const byte kInstruction_ssax_al_r13_r7_r8[] = {
  0xe7, 0xfa, 0x08, 0xfd // ssax al r13 r7 r8
};
const byte kInstruction_ssax_al_r9_r2_r8[] = {
  0xe2, 0xfa, 0x08, 0xf9 // ssax al r9 r2 r8
};
const byte kInstruction_ssax_al_r4_r13_r11[] = {
  0xed, 0xfa, 0x0b, 0xf4 // ssax al r4 r13 r11
};
const byte kInstruction_ssax_al_r4_r7_r14[] = {
  0xe7, 0xfa, 0x0e, 0xf4 // ssax al r4 r7 r14
};
const byte kInstruction_ssax_al_r7_r10_r4[] = {
  0xea, 0xfa, 0x04, 0xf7 // ssax al r7 r10 r4
};
const byte kInstruction_ssax_al_r10_r9_r12[] = {
  0xe9, 0xfa, 0x0c, 0xfa // ssax al r10 r9 r12
};
const byte kInstruction_ssax_al_r8_r13_r3[] = {
  0xed, 0xfa, 0x03, 0xf8 // ssax al r8 r13 r3
};
const byte kInstruction_ssax_al_r3_r7_r14[] = {
  0xe7, 0xfa, 0x0e, 0xf3 // ssax al r3 r7 r14
};
const byte kInstruction_ssax_al_r12_r0_r6[] = {
  0xe0, 0xfa, 0x06, 0xfc // ssax al r12 r0 r6
};
const byte kInstruction_ssax_al_r10_r9_r11[] = {
  0xe9, 0xfa, 0x0b, 0xfa // ssax al r10 r9 r11
};
const byte kInstruction_ssax_al_r3_r10_r1[] = {
  0xea, 0xfa, 0x01, 0xf3 // ssax al r3 r10 r1
};
const byte kInstruction_ssax_al_r5_r0_r11[] = {
  0xe0, 0xfa, 0x0b, 0xf5 // ssax al r5 r0 r11
};
const byte kInstruction_ssax_al_r8_r13_r2[] = {
  0xed, 0xfa, 0x02, 0xf8 // ssax al r8 r13 r2
};
const byte kInstruction_ssax_al_r5_r4_r10[] = {
  0xe4, 0xfa, 0x0a, 0xf5 // ssax al r5 r4 r10
};
const byte kInstruction_ssax_al_r3_r7_r2[] = {
  0xe7, 0xfa, 0x02, 0xf3 // ssax al r3 r7 r2
};
const byte kInstruction_ssax_al_r14_r14_r6[] = {
  0xee, 0xfa, 0x06, 0xfe // ssax al r14 r14 r6
};
const byte kInstruction_ssax_al_r6_r14_r13[] = {
  0xee, 0xfa, 0x0d, 0xf6 // ssax al r6 r14 r13
};
const byte kInstruction_ssax_al_r2_r2_r10[] = {
  0xe2, 0xfa, 0x0a, 0xf2 // ssax al r2 r2 r10
};
const byte kInstruction_ssax_al_r5_r13_r2[] = {
  0xed, 0xfa, 0x02, 0xf5 // ssax al r5 r13 r2
};
const byte kInstruction_ssax_al_r7_r14_r9[] = {
  0xee, 0xfa, 0x09, 0xf7 // ssax al r7 r14 r9
};
const byte kInstruction_ssax_al_r5_r6_r7[] = {
  0xe6, 0xfa, 0x07, 0xf5 // ssax al r5 r6 r7
};
const byte kInstruction_ssax_al_r5_r3_r6[] = {
  0xe3, 0xfa, 0x06, 0xf5 // ssax al r5 r3 r6
};
const byte kInstruction_ssax_al_r2_r1_r14[] = {
  0xe1, 0xfa, 0x0e, 0xf2 // ssax al r2 r1 r14
};
const byte kInstruction_ssax_al_r13_r11_r10[] = {
  0xeb, 0xfa, 0x0a, 0xfd // ssax al r13 r11 r10
};
const byte kInstruction_ssax_al_r7_r9_r12[] = {
  0xe9, 0xfa, 0x0c, 0xf7 // ssax al r7 r9 r12
};
const byte kInstruction_ssax_al_r11_r14_r11[] = {
  0xee, 0xfa, 0x0b, 0xfb // ssax al r11 r14 r11
};
const byte kInstruction_ssax_al_r3_r10_r9[] = {
  0xea, 0xfa, 0x09, 0xf3 // ssax al r3 r10 r9
};
const byte kInstruction_ssax_al_r0_r4_r4[] = {
  0xe4, 0xfa, 0x04, 0xf0 // ssax al r0 r4 r4
};
const byte kInstruction_ssax_al_r5_r8_r3[] = {
  0xe8, 0xfa, 0x03, 0xf5 // ssax al r5 r8 r3
};
const byte kInstruction_ssax_al_r10_r5_r13[] = {
  0xe5, 0xfa, 0x0d, 0xfa // ssax al r10 r5 r13
};
const byte kInstruction_ssax_al_r8_r3_r12[] = {
  0xe3, 0xfa, 0x0c, 0xf8 // ssax al r8 r3 r12
};
const byte kInstruction_ssax_al_r2_r1_r12[] = {
  0xe1, 0xfa, 0x0c, 0xf2 // ssax al r2 r1 r12
};
const byte kInstruction_ssax_al_r6_r8_r7[] = {
  0xe8, 0xfa, 0x07, 0xf6 // ssax al r6 r8 r7
};
const byte kInstruction_ssax_al_r13_r13_r6[] = {
  0xed, 0xfa, 0x06, 0xfd // ssax al r13 r13 r6
};
const byte kInstruction_ssax_al_r7_r2_r3[] = {
  0xe2, 0xfa, 0x03, 0xf7 // ssax al r7 r2 r3
};
const byte kInstruction_ssax_al_r3_r6_r3[] = {
  0xe6, 0xfa, 0x03, 0xf3 // ssax al r3 r6 r3
};
const byte kInstruction_ssax_al_r6_r5_r7[] = {
  0xe5, 0xfa, 0x07, 0xf6 // ssax al r6 r5 r7
};
const TestResult kReferencessax[] = {
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r12_r2),
    kInstruction_ssax_al_r5_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r3_r12),
    kInstruction_ssax_al_r7_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r2_r10),
    kInstruction_ssax_al_r1_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r7_r1),
    kInstruction_ssax_al_r2_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r9_r0),
    kInstruction_ssax_al_r11_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r9_r10),
    kInstruction_ssax_al_r6_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r5_r0),
    kInstruction_ssax_al_r0_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r6_r6),
    kInstruction_ssax_al_r4_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r13_r1),
    kInstruction_ssax_al_r1_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r14_r8),
    kInstruction_ssax_al_r8_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r12_r11),
    kInstruction_ssax_al_r6_r12_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r2_r8),
    kInstruction_ssax_al_r7_r2_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r6_r7),
    kInstruction_ssax_al_r13_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r3_r13),
    kInstruction_ssax_al_r10_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r10_r2),
    kInstruction_ssax_al_r10_r10_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r2_r12),
    kInstruction_ssax_al_r3_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r9_r7),
    kInstruction_ssax_al_r0_r9_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r1_r5),
    kInstruction_ssax_al_r4_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r12_r1),
    kInstruction_ssax_al_r12_r12_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r12_r2),
    kInstruction_ssax_al_r4_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r3_r4),
    kInstruction_ssax_al_r9_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r11_r3),
    kInstruction_ssax_al_r13_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r1_r5),
    kInstruction_ssax_al_r5_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r6_r2),
    kInstruction_ssax_al_r14_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r2_r0),
    kInstruction_ssax_al_r1_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r8_r14),
    kInstruction_ssax_al_r1_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r9_r10),
    kInstruction_ssax_al_r12_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r2_r6),
    kInstruction_ssax_al_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r6_r2),
    kInstruction_ssax_al_r13_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r4_r3),
    kInstruction_ssax_al_r8_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r11_r3),
    kInstruction_ssax_al_r7_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r1_r13),
    kInstruction_ssax_al_r8_r1_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r11_r6),
    kInstruction_ssax_al_r1_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r3_r10),
    kInstruction_ssax_al_r2_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r9_r0),
    kInstruction_ssax_al_r0_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r6_r1),
    kInstruction_ssax_al_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r7_r10),
    kInstruction_ssax_al_r5_r7_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r14_r7),
    kInstruction_ssax_al_r10_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r2_r12),
    kInstruction_ssax_al_r8_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r12_r3),
    kInstruction_ssax_al_r11_r12_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r4_r13),
    kInstruction_ssax_al_r0_r4_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r0_r8),
    kInstruction_ssax_al_r13_r0_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r14_r12),
    kInstruction_ssax_al_r7_r14_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r11_r10),
    kInstruction_ssax_al_r8_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r13_r14),
    kInstruction_ssax_al_r8_r13_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r7_r1),
    kInstruction_ssax_al_r13_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r0_r14),
    kInstruction_ssax_al_r10_r0_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r4_r12),
    kInstruction_ssax_al_r6_r4_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r8_r12),
    kInstruction_ssax_al_r8_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r9_r4),
    kInstruction_ssax_al_r10_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r9_r8),
    kInstruction_ssax_al_r14_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r1_r0),
    kInstruction_ssax_al_r9_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r4_r11),
    kInstruction_ssax_al_r14_r4_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r1_r12),
    kInstruction_ssax_al_r13_r1_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r14_r5),
    kInstruction_ssax_al_r6_r14_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r7_r6),
    kInstruction_ssax_al_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r14_r0),
    kInstruction_ssax_al_r6_r14_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r5_r11),
    kInstruction_ssax_al_r7_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r10_r9),
    kInstruction_ssax_al_r9_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r5_r0),
    kInstruction_ssax_al_r4_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r11_r2),
    kInstruction_ssax_al_r3_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r4_r3),
    kInstruction_ssax_al_r1_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r14_r6),
    kInstruction_ssax_al_r13_r14_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r8_r13),
    kInstruction_ssax_al_r1_r8_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r2_r7),
    kInstruction_ssax_al_r4_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r11_r3),
    kInstruction_ssax_al_r1_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r3_r6),
    kInstruction_ssax_al_r9_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r10_r5),
    kInstruction_ssax_al_r0_r10_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r7_r2),
    kInstruction_ssax_al_r5_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r14_r9),
    kInstruction_ssax_al_r1_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r12_r11),
    kInstruction_ssax_al_r9_r12_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r11_r8),
    kInstruction_ssax_al_r0_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r10_r12),
    kInstruction_ssax_al_r9_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r5_r5),
    kInstruction_ssax_al_r8_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r3_r10),
    kInstruction_ssax_al_r10_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r5_r8),
    kInstruction_ssax_al_r13_r5_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r4_r2),
    kInstruction_ssax_al_r11_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r10_r7),
    kInstruction_ssax_al_r1_r10_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r4_r1),
    kInstruction_ssax_al_r12_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r14_r8),
    kInstruction_ssax_al_r11_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r11_r8),
    kInstruction_ssax_al_r1_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r11_r10),
    kInstruction_ssax_al_r3_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r7_r0),
    kInstruction_ssax_al_r6_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r13_r9),
    kInstruction_ssax_al_r6_r13_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r14_r0),
    kInstruction_ssax_al_r9_r14_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r8_r2),
    kInstruction_ssax_al_r6_r8_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r11_r12),
    kInstruction_ssax_al_r7_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r3_r0),
    kInstruction_ssax_al_r9_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r3_r5),
    kInstruction_ssax_al_r5_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r10_r8),
    kInstruction_ssax_al_r5_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r4_r13),
    kInstruction_ssax_al_r12_r4_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r12_r10),
    kInstruction_ssax_al_r7_r12_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r13_r11),
    kInstruction_ssax_al_r6_r13_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r3_r7),
    kInstruction_ssax_al_r5_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r4_r6),
    kInstruction_ssax_al_r11_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r2_r3),
    kInstruction_ssax_al_r10_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r2_r1),
    kInstruction_ssax_al_r0_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r5_r7),
    kInstruction_ssax_al_r11_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r10_r1),
    kInstruction_ssax_al_r14_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r4_r1),
    kInstruction_ssax_al_r1_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r10_r11),
    kInstruction_ssax_al_r9_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r8_r0),
    kInstruction_ssax_al_r6_r8_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r10_r11),
    kInstruction_ssax_al_r0_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r1_r4),
    kInstruction_ssax_al_r14_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r9_r5),
    kInstruction_ssax_al_r7_r9_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r4_r2),
    kInstruction_ssax_al_r13_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r6_r3),
    kInstruction_ssax_al_r5_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r4_r8),
    kInstruction_ssax_al_r13_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r11_r12),
    kInstruction_ssax_al_r11_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r12_r6),
    kInstruction_ssax_al_r3_r12_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r10_r1),
    kInstruction_ssax_al_r4_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r8_r12),
    kInstruction_ssax_al_r7_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r3_r3),
    kInstruction_ssax_al_r11_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r6_r6),
    kInstruction_ssax_al_r14_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r12_r1),
    kInstruction_ssax_al_r1_r12_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r5_r7),
    kInstruction_ssax_al_r13_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r10_r8),
    kInstruction_ssax_al_r6_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r13_r5),
    kInstruction_ssax_al_r7_r13_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r13_r4),
    kInstruction_ssax_al_r12_r13_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r0_r8),
    kInstruction_ssax_al_r7_r0_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r11_r9),
    kInstruction_ssax_al_r7_r11_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r9_r1),
    kInstruction_ssax_al_r8_r9_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r5_r10),
    kInstruction_ssax_al_r14_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r9_r14),
    kInstruction_ssax_al_r4_r9_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r14_r9),
    kInstruction_ssax_al_r10_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r1_r11),
    kInstruction_ssax_al_r0_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r0_r11),
    kInstruction_ssax_al_r11_r0_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r10_r7),
    kInstruction_ssax_al_r10_r10_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r12_r7),
    kInstruction_ssax_al_r8_r12_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r4_r10),
    kInstruction_ssax_al_r9_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r11_r14),
    kInstruction_ssax_al_r8_r11_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r4_r7),
    kInstruction_ssax_al_r8_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r9_r11),
    kInstruction_ssax_al_r13_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r5_r7),
    kInstruction_ssax_al_r2_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r6_r8),
    kInstruction_ssax_al_r9_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r4_r10),
    kInstruction_ssax_al_r2_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r9_r4),
    kInstruction_ssax_al_r2_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r8_r12),
    kInstruction_ssax_al_r12_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r12_r2),
    kInstruction_ssax_al_r0_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r11_r13),
    kInstruction_ssax_al_r4_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r12_r14),
    kInstruction_ssax_al_r7_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r10_r3),
    kInstruction_ssax_al_r4_r10_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r14_r7),
    kInstruction_ssax_al_r5_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r6_r10),
    kInstruction_ssax_al_r1_r6_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r10_r10),
    kInstruction_ssax_al_r0_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r3_r3),
    kInstruction_ssax_al_r6_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r14_r6),
    kInstruction_ssax_al_r2_r14_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r4_r2),
    kInstruction_ssax_al_r7_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r7_r9),
    kInstruction_ssax_al_r3_r7_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r4_r12),
    kInstruction_ssax_al_r0_r4_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r14_r11),
    kInstruction_ssax_al_r8_r14_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r8_r11),
    kInstruction_ssax_al_r2_r8_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r11_r8),
    kInstruction_ssax_al_r14_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r10_r12),
    kInstruction_ssax_al_r5_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r12_r5),
    kInstruction_ssax_al_r0_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r4_r7),
    kInstruction_ssax_al_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r2_r10),
    kInstruction_ssax_al_r5_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r0_r0),
    kInstruction_ssax_al_r14_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r14_r4),
    kInstruction_ssax_al_r1_r14_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r0_r2),
    kInstruction_ssax_al_r1_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r10_r7),
    kInstruction_ssax_al_r11_r10_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r10_r4),
    kInstruction_ssax_al_r13_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r1_r9),
    kInstruction_ssax_al_r13_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r1_r9),
    kInstruction_ssax_al_r8_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r3_r9),
    kInstruction_ssax_al_r6_r3_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r6_r8),
    kInstruction_ssax_al_r10_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r11_r9),
    kInstruction_ssax_al_r6_r11_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r13_r14),
    kInstruction_ssax_al_r1_r13_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r14_r12),
    kInstruction_ssax_al_r1_r14_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r1_r4),
    kInstruction_ssax_al_r0_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r13_r1),
    kInstruction_ssax_al_r8_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r14_r5),
    kInstruction_ssax_al_r7_r14_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r13_r8),
    kInstruction_ssax_al_r5_r13_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r10_r13),
    kInstruction_ssax_al_r11_r10_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r13_r2),
    kInstruction_ssax_al_r7_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r2_r13),
    kInstruction_ssax_al_r2_r2_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r7_r5),
    kInstruction_ssax_al_r1_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r6_r12),
    kInstruction_ssax_al_r12_r6_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r9_r11),
    kInstruction_ssax_al_r5_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r7_r1),
    kInstruction_ssax_al_r12_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r9_r9),
    kInstruction_ssax_al_r13_r9_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r4_r13),
    kInstruction_ssax_al_r10_r4_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r2_r10),
    kInstruction_ssax_al_r9_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r5_r13),
    kInstruction_ssax_al_r1_r5_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r3_r9),
    kInstruction_ssax_al_r12_r3_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r3_r0),
    kInstruction_ssax_al_r6_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r8_r8),
    kInstruction_ssax_al_r9_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r3_r4),
    kInstruction_ssax_al_r6_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r9_r0),
    kInstruction_ssax_al_r12_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r10_r0),
    kInstruction_ssax_al_r4_r10_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r13_r4),
    kInstruction_ssax_al_r3_r13_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r10_r14),
    kInstruction_ssax_al_r2_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r9_r8),
    kInstruction_ssax_al_r3_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r4_r8),
    kInstruction_ssax_al_r12_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r1_r11),
    kInstruction_ssax_al_r2_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r7_r0),
    kInstruction_ssax_al_r1_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r1_r2),
    kInstruction_ssax_al_r0_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r12_r7),
    kInstruction_ssax_al_r11_r12_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r14_r7),
    kInstruction_ssax_al_r12_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r3_r10),
    kInstruction_ssax_al_r0_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r6_r7),
    kInstruction_ssax_al_r3_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r10_r1),
    kInstruction_ssax_al_r0_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r11_r5),
    kInstruction_ssax_al_r8_r11_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r10_r8),
    kInstruction_ssax_al_r1_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r8_r5),
    kInstruction_ssax_al_r7_r8_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r9_r2),
    kInstruction_ssax_al_r9_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r13_r0),
    kInstruction_ssax_al_r13_r13_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r10_r5),
    kInstruction_ssax_al_r9_r10_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r6_r14),
    kInstruction_ssax_al_r6_r6_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r8_r5),
    kInstruction_ssax_al_r1_r8_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r4_r8),
    kInstruction_ssax_al_r1_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r2_r12),
    kInstruction_ssax_al_r0_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r14_r1),
    kInstruction_ssax_al_r5_r14_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r1_r5),
    kInstruction_ssax_al_r2_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r11_r6),
    kInstruction_ssax_al_r11_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r11_r1),
    kInstruction_ssax_al_r3_r11_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r14_r9),
    kInstruction_ssax_al_r13_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r1_r5),
    kInstruction_ssax_al_r7_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r14_r3),
    kInstruction_ssax_al_r10_r14_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r6_r14),
    kInstruction_ssax_al_r5_r6_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r7_r7),
    kInstruction_ssax_al_r1_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r5_r14),
    kInstruction_ssax_al_r12_r5_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r5_r1),
    kInstruction_ssax_al_r10_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r8_r3),
    kInstruction_ssax_al_r10_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r6_r5),
    kInstruction_ssax_al_r4_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r3_r2),
    kInstruction_ssax_al_r4_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r13_r13),
    kInstruction_ssax_al_r10_r13_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r10_r4),
    kInstruction_ssax_al_r1_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r10_r12),
    kInstruction_ssax_al_r8_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r0_r13),
    kInstruction_ssax_al_r6_r0_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r12_r0),
    kInstruction_ssax_al_r1_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r13_r1),
    kInstruction_ssax_al_r4_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r0_r0),
    kInstruction_ssax_al_r10_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r6_r4),
    kInstruction_ssax_al_r13_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r3_r14),
    kInstruction_ssax_al_r0_r3_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r11_r2),
    kInstruction_ssax_al_r7_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r11_r12),
    kInstruction_ssax_al_r9_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r14_r7),
    kInstruction_ssax_al_r2_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r14_r8),
    kInstruction_ssax_al_r10_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r3_r2),
    kInstruction_ssax_al_r1_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r1_r8),
    kInstruction_ssax_al_r0_r1_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r9_r13),
    kInstruction_ssax_al_r2_r9_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r3_r5),
    kInstruction_ssax_al_r2_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r9_r3),
    kInstruction_ssax_al_r13_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r8_r8),
    kInstruction_ssax_al_r3_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r8_r7),
    kInstruction_ssax_al_r0_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r14_r7),
    kInstruction_ssax_al_r9_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r3_r11),
    kInstruction_ssax_al_r10_r3_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r14_r13),
    kInstruction_ssax_al_r1_r14_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r4_r1),
    kInstruction_ssax_al_r14_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r12_r4),
    kInstruction_ssax_al_r12_r12_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r12_r0),
    kInstruction_ssax_al_r0_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r1_r5_r1),
    kInstruction_ssax_al_r1_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r9_r6),
    kInstruction_ssax_al_r3_r9_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r11_r0),
    kInstruction_ssax_al_r2_r11_r0,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r6_r11),
    kInstruction_ssax_al_r2_r6_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r12_r8),
    kInstruction_ssax_al_r8_r12_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r12_r10),
    kInstruction_ssax_al_r2_r12_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r4_r10),
    kInstruction_ssax_al_r4_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r14_r7),
    kInstruction_ssax_al_r6_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r10_r14),
    kInstruction_ssax_al_r11_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r0_r5),
    kInstruction_ssax_al_r13_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r3_r7),
    kInstruction_ssax_al_r4_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r7_r8),
    kInstruction_ssax_al_r13_r7_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r9_r2_r8),
    kInstruction_ssax_al_r9_r2_r8,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r13_r11),
    kInstruction_ssax_al_r4_r13_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r4_r7_r14),
    kInstruction_ssax_al_r4_r7_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r10_r4),
    kInstruction_ssax_al_r7_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r9_r12),
    kInstruction_ssax_al_r10_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r13_r3),
    kInstruction_ssax_al_r8_r13_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r7_r14),
    kInstruction_ssax_al_r3_r7_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r12_r0_r6),
    kInstruction_ssax_al_r12_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r9_r11),
    kInstruction_ssax_al_r10_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r10_r1),
    kInstruction_ssax_al_r3_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r0_r11),
    kInstruction_ssax_al_r5_r0_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r13_r2),
    kInstruction_ssax_al_r8_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r4_r10),
    kInstruction_ssax_al_r5_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r7_r2),
    kInstruction_ssax_al_r3_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r14_r14_r6),
    kInstruction_ssax_al_r14_r14_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r14_r13),
    kInstruction_ssax_al_r6_r14_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r2_r10),
    kInstruction_ssax_al_r2_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r13_r2),
    kInstruction_ssax_al_r5_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r14_r9),
    kInstruction_ssax_al_r7_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r6_r7),
    kInstruction_ssax_al_r5_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r3_r6),
    kInstruction_ssax_al_r5_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r1_r14),
    kInstruction_ssax_al_r2_r1_r14,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r11_r10),
    kInstruction_ssax_al_r13_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r9_r12),
    kInstruction_ssax_al_r7_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r11_r14_r11),
    kInstruction_ssax_al_r11_r14_r11,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r10_r9),
    kInstruction_ssax_al_r3_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r0_r4_r4),
    kInstruction_ssax_al_r0_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r5_r8_r3),
    kInstruction_ssax_al_r5_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r10_r5_r13),
    kInstruction_ssax_al_r10_r5_r13,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r8_r3_r12),
    kInstruction_ssax_al_r8_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r2_r1_r12),
    kInstruction_ssax_al_r2_r1_r12,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r8_r7),
    kInstruction_ssax_al_r6_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r13_r13_r6),
    kInstruction_ssax_al_r13_r13_r6,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r7_r2_r3),
    kInstruction_ssax_al_r7_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r3_r6_r3),
    kInstruction_ssax_al_r3_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_ssax_al_r6_r5_r7),
    kInstruction_ssax_al_r6_r5_r7,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_RM_SSAX_T32_H_
